summaryrefslogtreecommitdiff
path: root/cpio/test/test.h
diff options
context:
space:
mode:
authorMichihiro NAKAJIMA <ggcueroad@gmail.com>2012-10-14 14:08:46 +0900
committerMichihiro NAKAJIMA <ggcueroad@gmail.com>2012-10-14 14:08:46 +0900
commitd857349722b642d2561238ebc5883e83eae161a2 (patch)
tree3bfa5ebd428a2b16f8f7771849497949f354fe2e /cpio/test/test.h
parent5fa19d2720aef965e88d297f5c58cac556c41f03 (diff)
downloadlibarchive-d857349722b642d2561238ebc5883e83eae161a2.tar.gz
Switch an external program for lzma decompression from "unlzma" to
"lzma -d".
Diffstat (limited to 'cpio/test/test.h')
-rw-r--r--cpio/test/test.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/cpio/test/test.h b/cpio/test/test.h
index 823d6541..6fc11d8c 100644
--- a/cpio/test/test.h
+++ b/cpio/test/test.h
@@ -281,8 +281,8 @@ int canLrzip(void);
/* Return true if this platform can run the "lzip" program. */
int canLzip(void);
-/* Return true if this platform can run the "unlzma" program. */
-int canUnlzma(void);
+/* Return true if this platform can run the "lzma" program. */
+int canLzma(void);
/* Return true if this platform can run the "lzop" program. */
int canLzop(void);